# Remove symlinks from /lib/modules/$krel/weak-updates/.
if [ -x /usr/lib/module-init-tools/weak-modules ]; then
    /usr/lib/module-init-tools/weak-modules\
	--remove-kernel @KERNELRELEASE@
fi

if [ -L /boot/vmlinux ]; then
    image=vmlinux
elif [ -L /boot/vmlinuz ]; then
    image=vmlinuz
elif [ -L /boot/image ]; then
    image=image
else
    # nothing to do (UML kernels for example).
    exit 0
fi

suffix=
case @FLAVOR@ in
    (kdump|um|xen*)
	suffix=-@FLAVOR@
	;;
esac

update_bootloader() {
    [ -x /sbin/update-bootloader -a \
      "$YAST_IS_RUNNING" != instsys ] || return 0
    /sbin/update-bootloader "$@"
}

# Somewhen in the future: use the real image and initrd filenames instead
# of the symlinks, and add/remove by the real filenames.
#    update_bootloader --image /boot/$image-@KERNELRELEASE@ \
#		       --initrd /boot/initrd-@KERNELRELEASE@ \
#		       --name @KERNELRELEASE@ --remove --force

if [ "$(readlink /boot/$image$suffix)" = $image-@KERNELRELEASE@ ]; then
    # This may be the last kernel RPM on the system, or it may
    # be an update. In both of those cases the symlinks will
    # eventually be correct. Only if this kernel
    # is removed and other kernel rpms remain installed,
    # find the most recent of the remaining kernels, and make
    # the symlinks point to it. This makes sure that the boot
    # manager will always have a kernel to boot in its default
    # configuration.
    shopt -s nullglob
    for this_image in $(cd /boot ; ls -dt $image-*); do
	this_initrd=initrd-${this_image#*-}
	if [ -f /boot/$this_image -a -f /boot/$this_initrd ]; then
	    relink $this_image /boot/$image$suffix
	    relink $this_initrd /boot/initrd$suffix

	    # Notify the boot loader that a new kernel image is active.
	    refresh_bootloader=1
	    break
	fi
    done
    shopt -u nullglob
fi

# Created in the other kernel's %post
case "$(readlink /boot/$image$suffix.previous)" in
$image-@KERNELRELEASE@|$(readlink /boot/$image$suffix))
    update_bootloader --image /boot/$image$suffix.previous \
		      --initrd /boot/initrd$suffix.previous \
		      --remove --force
    refresh_bootloader=1
    rm -f /boot/$image$suffix.previous 
    ;;
esac
case "$(readlink /boot/initrd$suffix.previous)" in
initrd-@KERNELRELEASE@|$(readlink /boot/initrd$suffix))
    rm -f /boot/initrd$suffix.previous ;;
esac

# Run the bootloader (e.g., lilo).
if [ -n "$refresh_bootloader" ]; then
    update_bootloader --refresh
fi
